@@ -4,19 +4,22 @@ use Moose;
 # ABSTRACT: An plugin bundle for all distributions by WATERKIP
 # KEYWORDS: author bundle distribution tool
 
-use Moose::Util::TypeConstraints qw(enum subtype where);
+use Data::Dumper;
 use List::Util qw(uniq any first);
+use Moose::Util::TypeConstraints qw(enum subtype where);
 use namespace::autoclean;
 
 # Use all the modules so we don't get weird dependency issues
 use Dist::Zilla::App::Command::xtest                  ();
+use Dist::Zilla::Plugin::ContributorsFile             ();
+use Dist::Zilla::Plugin::Git::Contributors            ();
 use Dist::Zilla::Plugin::CheckExtraTests              ();
+use Dist::Zilla::Plugin::CopyFilesFromBuild::Filtered ();
 use Dist::Zilla::Plugin::MinimumPerl                  ();
 use Dist::Zilla::Plugin::PodWeaver                    ();
 use Dist::Zilla::Plugin::Prereqs::AuthorDeps          ();
 use Dist::Zilla::Plugin::PromptIfStale                ();
 use Dist::Zilla::Plugin::Repository                   ();
-use Dist::Zilla::Plugin::CopyFilesFromBuild::Filtered ();
 use Dist::Zilla::PluginBundle::Filter                 ();
 use Dist::Zilla::PluginBundle::Git::VersionManager    ();
 use Dist::Zilla::PluginBundle::TestingMania           ();
@@ -24,7 +27,7 @@ use Dist::Zilla::Role::PluginBundle                   ();
 use Dist::Zilla::Role::PluginBundle::Easy             ();
 use Dist::Zilla::Util                                 ();
 
-our $VERSION = '1.8';
+our $VERSION = '1.9';
 
 with
     'Dist::Zilla::Role::PluginBundle::Easy',
@@ -88,7 +91,7 @@ around copy_files_from_build => sub {
     my $self = shift;
     sort(uniq(
             $self->$orig(@_),
-            qw(Makefile.PL cpanfile Build.PL README)
+            qw(Makefile.PL cpanfile Build.PL README README.md CONTRIBUTORS)
     ));
 };
 
@@ -177,7 +180,7 @@ sub _warn_me {
 
 sub commit_files_after_release {
     grep { -e } sort(uniq(
-            'README.md', 'README.pod',
+            'README.pod',
             'Changes',   shift->copy_files_from_release
     ));
 }
@@ -209,7 +212,6 @@ sub configure {
     my $self = shift;
 
     if ($self->debug) {
-        use Data::Dumper;
         _warn_me(Dumper { payload => $self->payload, });
     }
 
@@ -248,36 +250,37 @@ sub configure {
         qw(Readme ExecDir ShareDir MakeMaker Manifest
             TestRelease PodWeaver),
 
+        ['Git::Contributors'    => { order_by => 'commits' }],
+        ['ContributorsFile' => { filename => 'CONTRIBUTORS' }],
+
         ['AutoPrereqs'         => { skip       => [qw(^perl$)] }],
         ['Prereqs::AuthorDeps' => { ':version' => '0.006' }],
         [
             'MinimumPerl' =>
-                { ':version' => '1.006', configure_finder => ':NoFiles' }
+                { ':version' => '1.006',
+                    configure_finder => ':NoFiles'
+                }
         ],
 
         ['CPANFile'],
 
-        [ 'CopyFilesFromBuild::Filtered' => { copy => [ $self->copy_files_from_build ] } ],
+        [ 'CopyFilesFromBuild::Filtered' => {
+            copy => [ $self->copy_files_from_build ]
+        }],
 
-        #['Test::CPAN::Changes'],
         ['Repository'],
         ['ConfirmRelease'],
 
-        #        [ 'PrereqsClean'],
+        # This plugin seems cool, but also unmaintained with downstream
+        # deps which are also unmaintained. ABORT
+        #[ 'PrereqsClean'],
 
         $self->release_option,
 
-        # Perhaps do copy files from build first?
         [
             'CopyFilesFromRelease' =>
                 { filename => [$self->copy_files_from_release] }
         ],
-
-        # Don't generate a change log from git just yet, figure out
-        # first what our workflow will be
-        #['ChangelogFromGit' => { include_message => '^release' } ],
-
-
     );
 
     if ($self->airplane) {
@@ -357,7 +360,7 @@ Dist::Zilla::PluginBundle::Author::WATERKIP - An plugin bundle for all distribut
 
 =head1 VERSION
 
-version 1.8
+version 1.9
 
 =head1 SYNOPSIS
 
